``collective`` Package
======================

:mod:`collective` Package
----------------------------

.. automodule:: collective
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    collective.celery

